# Overview of build options: (Originally in zaptel.spec)
#
# If you have an SMP box use this option when building:
# --with smp
# Example:
# $ rpmbuild -bb rhino.spec --with smp
#
# Other options that allow you to build zaptel drivers for another
# kernel than the one you are currently running
#
# --define "kvers kernelver" - Build for kernel <version> instead of the
#                              current one. If you encounter problems then
#                              also define ksrc
#
# --define "ksrc /lib/modules/2.6.18-1.2798.fc6/build"
#
# Examples:
#
# To rebuild whole package for the running kernel:
# rpmbuild -ba THIS.SPEC --target "$(uname -m)" 
#
# To rebuild the zaptel kernel modules against a certain installed kernel
# like 2.6.16-1.2133_FC5:
# rpmbuild -ba THIS.SPEC --target "$(uname -m)" \
#          --define "kvers 2.6.18-1.2798.fc6"
#
# if you have problems try this:
# rpmbuild -ba THIS.SPEC --target "$(uname -m)" \
#          --define "kvers 2.6.18-1.2798.fc6" \
#          --define "ksrc /lib/modules/2.6.18-1.2798.fc6/build"
#
# End of build options.
%{!?kvers:      %{expand: %%define kvers %(uname -r)}}
%{!?ZAPVER:      %{expand: %%define ZAPVER 1.2.18}}

# force _smp_mflags to -j1
%define _smp-mflags -j1

%define _libmoddir /lib/modules
Name:           rhino-%{kvers}
Version:        1.1.1
Release:        7%{?dist}%{?_with_smp:_SMP}
Summary:        Kernel Module - Rhino Drivers

Group:          System Environment/Libraries
License:        LGPL
URL:            http://www.rhinoequiptment.com
Source0:        http://ftp.rhinoequiptment.com/Drivers/rhino-%{version}.tbz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

%define ZAPBUILDDIR /usr/src/redhat/BUILD/zaptel-%{ZAPVER}
#BuildRequires:  zaptel-devel

%description
Rhino Equipment kernel modules. This package is built for %{?_with_smp:SMP} kernel %{kvers} (%{_target_cpu}).

%prep
%setup -q -n rhino-%{version}

%build
[ "%{buildroot}" != '/' ] && rm -rf %{buildroot}
%{__make} %{?_smp_mflags} KVER="%{?kvers:%{kvers}}%{!?kvers:%{kernel}}" ZAPDIR="%{ZAPBUILDDIR}" INSTALL_PREFIX=%{buildroot}

%install
mkdir -p %{buildroot}/lib/firmware
%{makeinstall} %{?_smp_mflags} KVER="%{?kvers:%{kvers}}%{!?kvers:%{kernel}}" INSTALL_PREFIX=%{buildroot} ZAPDIR="%{ZAPBUILDDIR}"
/sbin/ldconfig -n %{buildroot}%{_libdir}

%clean
#[ "%{buildroot}" != '/' ] && rm -rf %{buildroot}

%pre
# make sure the asterisk user/group exists. Otherwise udev will make
# root own the /dev/zap/* devices while asterisk should own them

# if not exist add the asterisk group/user
grep -c "^asterisk:" %{_sysconfdir}/group &> /dev/null
if [ $? = 1 ]; then /usr/sbin/groupadd -r -f asterisk; fi
grep -c "^asterisk:" %{_sysconfdir}/passwd &> /dev/null
if [ $? = 1 ]; then /usr/sbin/useradd -c "Asterisk VoIP PBX" -g asterisk -r -s /sbin/nologin -m -d %{_localstatedir}/lib/asterisk asterisk; fi

%preun

%post
if ! /bin/grep 'MODULES="$MODULES rxt1"' /etc/sysconfig/zaptel >/dev/null 2>&1; then
 echo 'MODULES="$MODULES rxt1"         # Rhino Dual and Quad-span T1/E1/J1 PCI Interface Card"' >> /etc/sysconfig/zaptel
fi

if ! /bin/grep 'MODULES="$MODULES r4fxo"' /etc/sysconfig/zaptel >/dev/null 2>&1; then
 echo 'MODULES="$MODULES r4fxo"        # Rhino 4 Channel Analog PCI FXO Interface Card"' >> /etc/sysconfig/zaptel
fi

if ! /bin/grep 'MODULES="$MODULES r1t1"' /etc/sysconfig/zaptel >/dev/null 2>&1; then
 echo 'MODULES="$MODULES r1t1"         # Rhino Single-span T1/E1/J1 PCI Interface Card"' >> /etc/sysconfig/zaptel
fi

if ! /bin/grep 'MODULES="$MODULES rcbfx"' /etc/sysconfig/zaptel >/dev/null 2>&1; then
 echo 'MODULES="$MODULES rcbfx"        # Rhino 4/8/12/24 Channel Analog PCI Interface Card"' >> /etc/sysconfig/zaptel
fi

# update the ld database
/sbin/ldconfig

# make sure the kernel knows about the new rhino modules
/sbin/depmod -aeF /boot/System.map-%{kvers} %{kvers} > /dev/null || :

%postun
# update the ld database
/sbin/ldconfig

# make sure the kernel knows the rhino modules are gone
/sbin/depmod -aF /boot/System.map-%{kvers} %{kvers} &> /dev/null || :

%files
%attr(0744,root,root)	%{_libmoddir}/*
%{_libmoddir}/*
/lib/firmware/*

%changelog
* Wed May 02 2007 Doug Pedley trixbox.org 1.1.1
- Updated to rhino-1.1.1.tbz2
* Thu May 02 2007 Trixbox Admin <admin@trixbox.org> 1.1.0-6
- Cleaned Spec and rolled version
* Wed May 02 2007 Trixbox Admin <admin@trixbox.org> 1.1.0-5
- Updated to rhino-1.1.0.tbz2
- Added module defines to /etc/sysconfig/zaptel
* Mon Apr 30 2007 Trixbox Admin <admin@trixbox.org> 1.0.0-3
- added forcedeth.ko module to update kernel
* Mon Apr 30 2007 Trixbox Admin <admin@trixbox.org> 1.0.0-3
- updated to zaptel 1.2.17.1
* Tue Apr 17 2007 Trixbox Admin <admin@trixbox.org> 1.0.0-3
- removes service calls, they are not needed.
* Tue Apr 17 2007 Trixbox Admin <admin@trixbox.org> 1.0.0-2
- lib firmware added to the files section
* Mon Apr 16 2007 Trixbox Admin <admin@trixbox.org> 1.0.0-1
- Initial Build
